Stats
====================

This module contains functions for calculating statistics, like ADR, KAST and Rating, on Counter-Strik 2 demo files.

awpy.stats
------------------------------

.. automodule:: awpy.stats
   :members:
   :undoc-members:
   :show-inheritance: